@@ -1,9 +1,31 @@
+#
+# Copyright (c) 2013+ Anton Tyurin <noxiouz@yandex.ru>
+# Copyright (c) 2013+ Evgeny Safronov <division494@gmail.com>
+# Copyright (c) 2011-2014 Other contributors as noted in the AUTHORS file.
+#
+# This file is part of Cocaine-tools.
+#
+# Cocaine is free software; you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published
+# by the Free Software Foundation; either version 3 of the License, or
+# (at your option) any later version.
+#
+# Cocaine is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
+#
+
 import ast
 import re
 
 from cocaine.exceptions import ServiceError
 from cocaine.futures import chain
 from cocaine.services import Service
+from cocaine.tools.actions import profile
 from cocaine.tools.error import ServiceCallError
 
 __author__ = 'Evgeny Safronov <division494@gmail.com>'
@@ -18,26 +40,38 @@ class Node(object):
 
 
 class NodeInfo(Node):
-    def __init__(self, node, locator):
+    def __init__(self, node, locator, storage, name=None, expand=False):
         super(NodeInfo, self).__init__(node)
         self.locator = locator
+        self._storage = storage
+        self._name = name
+        self._expand = expand
 
     @chain.source
     def execute(self):
-        appNames = yield self.node.list()
-        appInfoList = {}
-        for appName in appNames:
+        if self._name:
+            apps = [self._name]
+        else:
+            apps = yield self.node.list()
+        yield self.info(apps)
+
+    @chain.source
+    def info(self, apps):
+        infos = {}
+        for app_ in apps:
             info = ''
             try:
-                app = Service(appName, blockingConnect=False)
+                app = Service(app_, blockingConnect=False)
                 yield app.connectThroughLocator(self.locator)
                 info = yield app.info()
+                if all([self._expand, self._storage is not None, 'profile' in info]):
+                    info['profile'] = yield profile.View(self._storage, info['profile']).execute()
             except Exception as err:
                 info = str(err)
             finally:
-                appInfoList[appName] = info
+                infos[app_] = info
         result = {
-            'apps': appInfoList
+            'apps': infos
         }
         yield result
 
