@@ -1,5 +1,27 @@
+#
+# Copyright (c) 2013+ Anton Tyurin <noxiouz@yandex.ru>
+# Copyright (c) 2013+ Evgeny Safronov <division494@gmail.com>
+# Copyright (c) 2011-2014 Other contributors as noted in the AUTHORS file.
+#
+# This file is part of Cocaine-tools.
+#
+# Cocaine is free software; you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published
+# by the Free Software Foundation; either version 3 of the License, or
+# (at your option) any later version.
+#
+# Cocaine is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
+#
+
 import base64
 import json
+import os
 import tarfile
 import StringIO
 import urllib
@@ -11,6 +33,7 @@ from tornado.ioloop import IOLoop
 from cocaine.tools import log
 from cocaine.futures import chain
 from cocaine.tools.helpers._unix import AsyncUnixHTTPClient
+from cocaine.tools.helpers.dockertemplate import dockerchef, dockerpuppet
 
 __author__ = 'Evgeny Safronov <division494@gmail.com>'
 
@@ -33,7 +56,7 @@ def resolve_repository_name(fullname):
         raise ValueError('repository name can not contain a scheme ({0})'.format(fullname))
 
     parts = fullname.split('/', 1)
-    if not '.' in parts[0] and not ':' in parts[0] and parts[0] != 'localhost':
+    if '.' not in parts[0] and ':' not in parts[0] and parts[0] != 'localhost':
         return DEFAULT_INDEX_URL, fullname
 
     if len(parts) < 2:
@@ -141,7 +164,7 @@ class Build(Action):
         else:
             log.info('Local path detected. Creating archive "%s"... ', self._path)
             headers = {'Content-Type': 'application/tar'}
-            body = self._tar(self._path)
+            body = self.make_env(self._path)
             log.info('OK')
 
         query = {'t': self._tag, 'remote': remote, 'q': self._quiet}
@@ -167,6 +190,32 @@ class Build(Action):
         finally:
             stream.close()
 
+    def make_env(self, path):
+        if os.path.exists(os.path.join(path, "Dockerfile")):
+            log.info("Dockerfile exists")
+            return self._tar(path)
+        elif os.path.isdir(os.path.join(path, "cookbooks")):
+            log.info("Chef has been detected")
+            dockfilecontent = dockerchef.generate(basecontainer="ubuntu:precise",
+                                                  cookbooks="cookbooks")
+        elif os.path.isdir(os.path.join(path, "puppet")):
+            log.info("Puppet has been detected")
+            if not os.path.exists(os.path.join(path, "puppet/cocaine.pp")):
+                raise ValueError("You have to name your own Puppet manifest 'cocaine.pp'")
+
+            dockfilecontent = dockerpuppet.generate(basecontainer="ubuntu:precise")
+        else:
+            raise ValueError("Please, create Dockerfile or Puppet manifest or Chef recipe")
+
+        log.info("Generate Dockerfile")
+        print(dockfilecontent)
+        with open("Dockerfile", "w") as dockerfile:
+            dockerfile.write(dockfilecontent)
+        try:
+            return self._tar(path)
+        finally:
+            os.unlink("Dockerfile")
+
 
 class Push(Action):
     def __init__(self, name, auth, streaming=None,
