@@ -1,3 +1,24 @@
+#
+# Copyright (c) 2013+ Anton Tyurin <noxiouz@yandex.ru>
+# Copyright (c) 2013+ Evgeny Safronov <division494@gmail.com>
+# Copyright (c) 2011-2014 Other contributors as noted in the AUTHORS file.
+#
+# This file is part of Cocaine-tools.
+#
+# Cocaine is free software; you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published
+# by the Free Software Foundation; either version 3 of the License, or
+# (at your option) any later version.
+#
+# Cocaine is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
+#
+
 import errno
 import json
 import msgpack
@@ -7,9 +28,9 @@ from tornado.ioloop import IOLoop
 
 from cocaine.exceptions import ChokeEvent, CocaineError
 from cocaine.futures import chain
+from cocaine.tools import log, interactive
 from cocaine.tools.actions import common, app, profile, runlist, crashlog, group
 from cocaine.tools.error import Error as ToolsError
-from cocaine.tools import log
 
 
 __author__ = 'EvgenySafronov <division494@gmail.com>'
@@ -60,8 +81,8 @@ class CrashlogStatusToolHandler(ToolHandler):
         key = lambda (app, (timestamp, time_, uuid), total): timestamp
 
         log.info(self.HEADER)
-        for app, (timestamp, time_, uuid), total in sorted(result, key=key):
-            print(self.FORMAT_CONTENT.format(app, total, time, uuid))
+        for appname, (timestamp, time_, uuid), total in sorted(result, key=key):
+            print(self.FORMAT_CONTENT.format(appname, total, time, uuid))
 
 
 class CrashlogListToolHandler(ToolHandler):
@@ -74,8 +95,8 @@ class CrashlogListToolHandler(ToolHandler):
             return
 
         log.info(self.HEADER)
-        for timestamp, time, uuid in sorted(crashlog._parseCrashlogs(result), key=lambda (ts, time, uuid): ts):
-            print(self.FORMAT_HEADER.format(timestamp, time, uuid))
+        for timestamp, caltime, uuid in sorted(crashlog._parseCrashlogs(result), key=lambda (ts, caltime, uuid): ts):
+            print(self.FORMAT_HEADER.format(timestamp, caltime, uuid))
 
 
 class CrashlogViewToolHandler(ToolHandler):
@@ -114,9 +135,11 @@ NG_ACTIONS = {
     'profile:view': JsonToolHandler(profile.View),
     'profile:upload': ToolHandler(profile.Upload),
     'profile:remove': ToolHandler(profile.Remove),
+    'profile:edit': ToolHandler(interactive.ProfileEditor),
 
     'runlist:list': JsonToolHandler(runlist.List),
     'runlist:view': JsonToolHandler(runlist.View),
+    'runlist:edit': ToolHandler(interactive.RunlistEditor),
     'runlist:add-app': JsonToolHandler(runlist.AddApplication),
     'runlist:remove-app': JsonToolHandler(runlist.RemoveApplication),
     'runlist:create': ToolHandler(runlist.Create),
@@ -136,6 +159,7 @@ NG_ACTIONS = {
     'crashlog:view': CrashlogViewToolHandler(crashlog.View),
     'crashlog:remove': ToolHandler(crashlog.Remove),
     'crashlog:removeall': ToolHandler(crashlog.RemoveAll),
+    'crashlog:clean': ToolHandler(crashlog.Clean),
 }
 
 
